Stan Math Library: stan/math/prim/scal/prob/neg_binomial_2_rng.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
neg_binomial_2_rng.hpp File Reference
`#include <boost/math/special_functions/digamma.hpp>`
`#include <boost/random/negative_binomial_distribution.hpp>`
`#include <boost/random/variate_generator.hpp>`
`#include <stan/math/prim/scal/err/check_consistent_sizes.hpp>`
`#include <stan/math/prim/scal/err/check_positive_finite.hpp>`
`#include <stan/math/prim/scal/err/check_nonnegative.hpp>`
`#include <stan/math/prim/scal/err/check_less.hpp>`
`#include <stan/math/prim/scal/fun/constants.hpp>`
`#include <stan/math/prim/scal/fun/binomial_coefficient_log.hpp>`
`#include <stan/math/prim/scal/fun/multiply_log.hpp>`
`#include <stan/math/prim/scal/fun/digamma.hpp>`
`#include <stan/math/prim/scal/fun/lgamma.hpp>`
`#include <stan/math/prim/scal/fun/value_of.hpp>`
`#include <stan/math/prim/scal/meta/include_summand.hpp>`
`#include <stan/math/prim/scal/prob/gamma_rng.hpp>`
`#include <stan/math/prim/scal/prob/poisson_rng.hpp>`
`#include <stan/math/prim/scal/fun/grad_reg_inc_beta.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<class RNG >
int | stan::math::neg_binomial_2_rng (const double mu, const double phi, RNG &rng)

[ Stan Home Page ] © 2011–2016, Stan Development Team.